==> mingw-w64-notepad%2B%2B-8.6.4-1.src.tar.zst: notepad-plus-plus-8.6.4/PowerEditor/src/ScintillaComponent/colors.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#pragma once

const COLORREF red			            = RGB(0xFF,    0,    0);
const COLORREF darkRed                  = RGB(0x80,    0,    0);
const COLORREF offWhite		            = RGB(0xFF, 0xFB, 0xF0);
const COLORREF darkGreen	            = RGB(0,    0x80,    0);
const COLORREF liteGreen	            = RGB(0,    0xFF,    0);
const COLORREF blueGreen	            = RGB(0,    0x80, 0x80);
const COLORREF liteRed					= RGB(0xFF, 0xAA, 0xAA);
const COLORREF liteBlueGreen			= RGB(0xAA, 0xFF, 0xC8);

const COLORREF liteBlue		            = RGB(0xA6, 0xCA, 0xF0);
const COLORREF veryLiteBlue             = RGB(0xC4, 0xF9, 0xFD);
const COLORREF extremeLiteBlue          = RGB(0xF2, 0xF4, 0xFF);

const COLORREF darkBlue  	            = RGB(0,       0, 0x80);
const COLORREF blue      	            = RGB(0,       0, 0xFF);
const COLORREF black     	            = RGB(0,       0,    0);
const COLORREF white     	            = RGB(0xFF, 0xFF, 0xFF);
const COLORREF darkGrey      	        = RGB(64,     64,   64);
const COLORREF grey      	            = RGB(128,   128,  128);
const COLORREF liteGrey  	            = RGB(192,   192,  192);
const COLORREF veryLiteGrey  	        = RGB(224,   224,  224);
const COLORREF brown     	            = RGB(128,    64,    0);
//const COLORREF greenBlue 	            = RGB(192,   128,   64);
const COLORREF darkYellow				= RGB(0xFF, 0xC0,    0);
const COLORREF yellow    	            = RGB(0xFF, 0xFF,    0);
const COLORREF lightYellow				= RGB(0xFF, 0xFF, 0xD5);
const COLORREF cyan      	            = RGB(0,    0xFF, 0xFF);
const COLORREF orange		            = RGB(0xFF, 0x80, 0x00);
const COLORREF purple		            = RGB(0x80, 0x00, 0xFF);
const COLORREF deepPurple	            = RGB(0x87, 0x13, 0x97);

const COLORREF extremeLitePurple        = RGB(0xF8, 0xE8, 0xFF);
const COLORREF veryLitePurple           = RGB(0xE7, 0xD8, 0xE9);
const COLORREF liteBerge				= RGB(0xFE, 0xFC, 0xF5);
const COLORREF berge					= RGB(0xFD, 0xF8, 0xE3);

==> mingw-w64-notepad%2B%2B-8.6.9-1.src.tar.zst: notepad-plus-plus-8.6.9/PowerEditor/src/ScintillaComponent/colors.h <==
// This file is part of Notepad++ project
// Copyright (C)2021 Don HO <don.h@free.fr>

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// at your option any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <https://www.gnu.org/licenses/>.


#pragma once

const COLORREF red			            = RGB(0xFF,    0,    0);
const COLORREF darkRed                  = RGB(0x80,    0,    0);
const COLORREF offWhite		            = RGB(0xFF, 0xFB, 0xF0);
const COLORREF darkGreen	            = RGB(0,    0x80,    0);
const COLORREF liteGreen	            = RGB(0,    0xFF,    0);
const COLORREF blueGreen	            = RGB(0,    0x80, 0x80);
const COLORREF liteRed					= RGB(0xFF, 0xAA, 0xAA);
const COLORREF liteBlueGreen			= RGB(0xAA, 0xFF, 0xC8);

const COLORREF liteBlue		            = RGB(0xA6, 0xCA, 0xF0);
const COLORREF veryLiteBlue             = RGB(0xC4, 0xF9, 0xFD);
const COLORREF extremeLiteBlue          = RGB(0xF2, 0xF4, 0xFF);

const COLORREF darkBlue  	            = RGB(0,       0, 0x80);
const COLORREF blue      	            = RGB(0,       0, 0xFF);
const COLORREF black     	            = RGB(0,       0,    0);
const COLORREF white     	            = RGB(0xFF, 0xFF, 0xFF);
const COLORREF darkGrey      	        = RGB(64,     64,   64);
const COLORREF grey      	            = RGB(128,   128,  128);
const COLORREF liteGrey  	            = RGB(192,   192,  192);
const COLORREF veryLiteGrey  	        = RGB(224,   224,  224);
const COLORREF brown     	            = RGB(128,    64,    0);
//const COLORREF greenBlue 	            = RGB(192,   128,   64);
const COLORREF darkYellow				= RGB(0xFF, 0xC0,    0);
const COLORREF yellow    	            = RGB(0xFF, 0xFF,    0);
const COLORREF lightYellow				= RGB(0xFF, 0xFF, 0xD5);
const COLORREF cyan      	            = RGB(0,    0xFF, 0xFF);
const COLORREF orange		            = RGB(0xFF, 0x80, 0x00);
const COLORREF purple		            = RGB(0x80, 0x00, 0xFF);
const COLORREF deepPurple	            = RGB(0x87, 0x13, 0x97);

const COLORREF extremeLitePurple        = RGB(0xF8, 0xE8, 0xFF);
const COLORREF veryLitePurple           = RGB(0xE7, 0xD8, 0xE9);
const COLORREF liteBerge				= RGB(0xFE, 0xFC, 0xF5);
const COLORREF berge					= RGB(0xFD, 0xF8, 0xE3);


// Change History default colours. Modified uses existing orange colour
const COLORREF midGreen                 = RGB(0,    0xA0,    0); // saved
const COLORREF darkCyan                 = RGB(0x40, 0xA0, 0xBF); // revert origin
const COLORREF yellowGreen              = RGB(0xA0, 0xC0,    0); // revert modified
